pub struct TxQuery { /* private fields */ }Implementations
Sourceimpl TxQuery
impl TxQuery
pub fn new( tx_cache: TransactionCache, daemon: Daemon, mempool: Arc<Tracker>, header: Arc<HeaderQuery>, duration: Arc<HistogramVec>, network: Network, confirmed_index: Arc<DBStore>, ) -> TxQuery
Sourcepub async fn get(
&self,
txid: &Txid,
blockhash: Option<&BlockHash>,
blockheight: Option<u32>,
allow_by_txidem: bool,
) -> Result<Transaction>
pub async fn get( &self, txid: &Txid, blockhash: Option<&BlockHash>, blockheight: Option<u32>, allow_by_txidem: bool, ) -> Result<Transaction>
Get a transaction by Txid.
Sourcepub async fn get_unconfirmed(&self, txid: &Txid) -> Result<Transaction>
pub async fn get_unconfirmed(&self, txid: &Txid) -> Result<Transaction>
Get an transaction known to be unconfirmed.
This is slightly faster than get as it avoids blockhash lookup. May
or may not return the transaction even if it is confirmed.
pub async fn get_verbose( &self, txid_or_txidem: &Txid, allow_by_txidem: bool, ) -> Result<Value>
Sourcepub async fn get_confirmation_height(&self, txid: &Txid) -> Option<i64>
pub async fn get_confirmation_height(&self, txid: &Txid) -> Option<i64>
Returns the height the transaction is confirmed at.
If the transaction is in mempool, it return -1 if it has unconfirmed parents, or 0 if not.
Returns None if transaction does not exist.
Sourcepub async fn create_input_cache(
&self,
txids: &HashSet<Txid>,
) -> HashMap<OutPointHash, u64>
pub async fn create_input_cache( &self, txids: &HashSet<Txid>, ) -> HashMap<OutPointHash, u64>
Create input amount cache out of outsputs from given tx set, where possible.
Sourcepub async fn mempool_entry_from(
&self,
mempool: &Tracker,
tx: Transaction,
input_cache: &HashMap<OutPointHash, u64>,
) -> Result<MempoolEntry>
pub async fn mempool_entry_from( &self, mempool: &Tracker, tx: Transaction, input_cache: &HashMap<OutPointHash, u64>, ) -> Result<MempoolEntry>
Create a mempool entry for given transaction.
Note: We need to pass mempool, rather than use self.mempool to avoid dead lock, since we call this method from the mempool itself.
pub async fn get_mempool_entry( &self, mempool: &Tracker, txid: &Txid, input_cache: &HashMap<OutPointHash, u64>, ) -> Result<MempoolEntry>